🎮 Discord Stats
=============================================

Discord Interface
-------------------
.. automodule:: novauniverse.interfaces.stats.discord
   :members:
   :undoc-members:
   :show-inheritance:

Discord Stats Reference
------------------------
.. automodule:: novauniverse.interfaces.stats.discord.discord_stats
   :members:
   :undoc-members:
   :show-inheritance: